package virtualmachines

import (
	"context"
	"fmt"
	"net/http"

	"github.com/Azure/go-autorest/autorest"
	"github.com/Azure/go-autorest/autorest/azure"
	"github.com/hashicorp/go-azure-helpers/polling"
)

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See NOTICE.txt in the project root for license information.

type AssessPatchesOperationResponse struct {
	Poller       polling.LongRunningPoller
	HttpResponse *http.Response
}

// AssessPatches ...
func (c VirtualMachinesClient) AssessPatches(ctx context.Context, id VirtualMachineId) (result AssessPatchesOperationResponse, err error) {
	req, err := c.preparerForAssessPatches(ctx, id)
	if err != nil {
		err = autorest.NewErrorWithError(err, "virtualmachines.VirtualMachinesClient", "AssessPatches", nil, "Failure preparing request")
		return
	}

	result, err = c.senderForAssessPatches(ctx, req)
	if err != nil {
		err = autorest.NewErrorWithError(err, "virtualmachines.VirtualMachinesClient", "AssessPatches", result.HttpResponse, "Failure sending request")
		return
	}

	return
}

// AssessPatchesThenPoll performs AssessPatches then polls until it's completed
func (c VirtualMachinesClient) AssessPatchesThenPoll(ctx context.Context, id VirtualMachineId) error {
	result, err := c.AssessPatches(ctx, id)
	if err != nil {
		return fmt.Errorf("performing AssessPatches: %+v", err)
	}

	if err := result.Poller.PollUntilDone(); err != nil {
		return fmt.Errorf("polling after AssessPatches: %+v", err)
	}

	return nil
}

// preparerForAssessPatches prepares the AssessPatches request.
func (c VirtualMachinesClient) preparerForAssessPatches(ctx context.Context, id VirtualMachineId) (*http.Request, error) {
	queryParameters := map[string]interface{}{
		"api-version": defaultApiVersion,
	}

	preparer := autorest.CreatePreparer(
		autorest.AsContentType("application/json; charset=utf-8"),
		autorest.AsPost(),
		autorest.WithBaseURL(c.baseUri),
		autorest.WithPath(fmt.Sprintf("%s/assessPatches", id.ID())),
		autorest.WithQueryParameters(queryParameters))
	return preparer.Prepare((&http.Request{}).WithContext(ctx))
}

// senderForAssessPatches sends the AssessPatches request. The method will close the
// http.Response Body if it receives an error.
func (c VirtualMachinesClient) senderForAssessPatches(ctx context.Context, req *http.Request) (future AssessPatchesOperationResponse, err error) {
	var resp *http.Response
	resp, err = c.Client.Send(req, azure.DoRetryWithRegistration(c.Client))
	if err != nil {
		return
	}

	future.Poller, err = polling.NewPollerFromResponse(ctx, resp, c.Client, req.Method)
	return
}
