package artifacts

import (
	"context"
	"fmt"
	"net/http"

	"github.com/Azure/go-autorest/autorest"
	"github.com/Azure/go-autorest/autorest/azure"
)

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See NOTICE.txt in the project root for license information.

type GenerateArmTemplateOperationResponse struct {
	HttpResponse *http.Response
	Model        *ArmTemplateInfo
}

// GenerateArmTemplate ...
func (c ArtifactsClient) GenerateArmTemplate(ctx context.Context, id ArtifactId, input GenerateArmTemplateRequest) (result GenerateArmTemplateOperationResponse, err error) {
	req, err := c.preparerForGenerateArmTemplate(ctx, id, input)
	if err != nil {
		err = autorest.NewErrorWithError(err, "artifacts.ArtifactsClient", "GenerateArmTemplate", nil, "Failure preparing request")
		return
	}

	result.HttpResponse, err = c.Client.Send(req, azure.DoRetryWithRegistration(c.Client))
	if err != nil {
		err = autorest.NewErrorWithError(err, "artifacts.ArtifactsClient", "GenerateArmTemplate", result.HttpResponse, "Failure sending request")
		return
	}

	result, err = c.responderForGenerateArmTemplate(result.HttpResponse)
	if err != nil {
		err = autorest.NewErrorWithError(err, "artifacts.ArtifactsClient", "GenerateArmTemplate", result.HttpResponse, "Failure responding to request")
		return
	}

	return
}

// preparerForGenerateArmTemplate prepares the GenerateArmTemplate request.
func (c ArtifactsClient) preparerForGenerateArmTemplate(ctx context.Context, id ArtifactId, input GenerateArmTemplateRequest) (*http.Request, error) {
	queryParameters := map[string]interface{}{
		"api-version": defaultApiVersion,
	}

	preparer := autorest.CreatePreparer(
		autorest.AsContentType("application/json; charset=utf-8"),
		autorest.AsPost(),
		autorest.WithBaseURL(c.baseUri),
		autorest.WithPath(fmt.Sprintf("%s/generateArmTemplate", id.ID())),
		autorest.WithJSON(input),
		autorest.WithQueryParameters(queryParameters))
	return preparer.Prepare((&http.Request{}).WithContext(ctx))
}

// responderForGenerateArmTemplate handles the response to the GenerateArmTemplate request. The method always
// closes the http.Response Body.
func (c ArtifactsClient) responderForGenerateArmTemplate(resp *http.Response) (result GenerateArmTemplateOperationResponse, err error) {
	err = autorest.Respond(
		resp,
		azure.WithErrorUnlessStatusCode(http.StatusOK),
		autorest.ByUnmarshallingJSON(&result.Model),
		autorest.ByClosing())
	result.HttpResponse = resp

	return
}
